<?php
// BULK HOST IMPORT CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: bulkhostimport.inc.php 1261 2014-04-15 17:49:37Z swilkerson $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
bulkhostimport_configwizard_init();

function bulkhostimport_configwizard_init(){

    // only show this wizard to advanced users
    //if(is_advanced_user()==false)
    //  return;
    
    $name = "bulkhostimport";
    
    $args = array(
        CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
        CONFIGWIZARD_DESCRIPTION => gettext("Clones existing hosts quickly and easily.  Supports import from auto-discovery jobs and CSV input."),
        CONFIGWIZARD_DISPLAYTITLE => "Bulk Host Cloning and Import",
        CONFIGWIZARD_FUNCTION => "bulkhostimport_configwizard_func",
        CONFIGWIZARD_PREVIEWIMAGE => "bulkimport.png",
        CONFIGWIZARD_VERSION => 1.9,
        CONFIGWIZARD_DATE => "04/14/2014",
        );

    register_configwizard($name,$args);
}
    
function bulkhostimport_configwizard_checkversion()
{
    if (!function_exists('get_product_release'))
        return false;

    $ver = get_product_release();
    if ($ver < 206)
        return false;
    return true;
}
    

function bulkhostimport_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

    $wizard_name="bulkhostimport";
    
    // initialize return code and output
    $result=0;
    $output="";
    
    // initialize output args - pass back the same data we got
    $outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


    switch($mode) {

        case CONFIGWIZARD_MODE_GETSTAGE1HTML:
        
            $host = grab_array_var($inargs, "host", "");
            
            if (bulkhostimport_configwizard_checkversion() == false) {
                $output = '<p><strong>'.gettext('Error').':</strong> '.gettext('This wizard requires Nagios XI 2011R1.6 or later').'.</p>';
            } else {
        
                $output = '
                    <p>
                    '.gettext('This wizard allows you to clone existing hosts quicky and easily.  It supports import of new hosts in bulk.').'
                    </p>
                    <p>'.gettext('New host information is specified in CSV format and each newly imported host is given the same services as an existing host that is being monitored.  This is useful if you setup one host as a template and want to setup several other hosts using the same template').'.
                    </p>
                    
                    <br>

                    <div class="sectionTitle">'.gettext('Template Host Information').'</div>
                    
                            
                    <table>
                    
                    <tr>
                    <td valign="top">
                    <label>'.gettext('Host Name').':</label><br class="nobr" />
                    </td>
                    <td>
                    <select name="host">
                    <OPTION VALUE=""></OPTION>
                    ';
                    
                    $args = array("is_active" => 1);
                    $xmlhosts = get_xml_host_objects($args);
                    $hosts = array();
                    foreach($xmlhosts->host as $h) {
                        $hosts[] = $h;
                    }
                    $hosts = array_reverse($hosts);

                    foreach($hosts as $h){
                        $hname = strval($h->host_name);
                        $hdesc = $hname;
                        $halias = strval($h->alias);
                        if ($halias != $hname && $halias != "") {
                            $hdesc .= " (" . $halias . ")";
                        }
                        $output .= '<OPTION VALUE="'.$hname.'" '.is_selected($host, $hname).'>'.$hdesc.'</OPTION>';
                    }
                        
                    $output .= '
                    </select>
                    <br class="nobr" /><br>
                    '.gettext('Select an existing host that should be cloned and used as the template for new hosts').'.<br><br>
                    </td>
                    </tr>

                    </table>';
            }
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
        
            // Get variables that were passed to us
            $host = grab_array_var($inargs, "host", "");
            
            
            // Check for errors
            $errors = 0;
            $errmsg = array();

            if (bulkhostimport_configwizard_checkversion() == false) {
                $errmsg[$errors++]=gettext("Error: This wizard requires Nagios XI 2011R1.6 or later");
            }

            if (have_value($host) == false) {
                $errmsg[$errors++] = gettext("No template host specified.");
            } else if (host_exists($host) == false) {
                $errmsg[$errors++] = gettext("Template host could not be found.");
            }

            if ($errors > 0) {
                $outargs[CONFIGWIZARD_ERROR_MESSAGES] = $errmsg;
                $result = 1;
            }
                
            break;
            
        case CONFIGWIZARD_MODE_GETSTAGE2HTML:
        
            // Get variables that were passed to us
            $host = grab_array_var($inargs, "host");
            $csvdata = grab_array_var($inargs, "csvdata");
            $field1 = grab_array_var($inargs, "field1", "address");
            $field2 = grab_array_var($inargs, "field2");
            $field3 = grab_array_var($inargs, "field3");
            $field4 = grab_array_var($inargs, "field4");
            $field5 = grab_array_var($inargs, "field5");
            $overwrite = grab_array_var($inargs, "overwrite", 1);
			$field4=grab_array_var($inargs,"field5");
			$field5=grab_array_var($inargs,"field5");

            $services = "";           
            $services_serial = grab_array_var($inargs, "services_serial", "");
            if ($services_serial != "") {
                $services = unserialize(base64_decode($services_serial));
            }
            if (!is_array($services)) {
                $services_default = array();
                $services = grab_array_var($inargs, "services", $services_default);
            }

            $serviceargs = "";
            $serviceargs_serial = grab_array_var($inargs, "serviceargs_serial", "");
            if ($serviceargs_serial != "") {
                $serviceargs = unserialize(base64_decode($serviceargs_serial));
            }
            if (!is_array($serviceargs)) {
                $serviceargs_default = array();                  
                $serviceargs = grab_array_var($inargs, "serviceargs", $serviceargs_default);
            }
            

            
        
            $output = '
            <script type="text/javascript">
                //check all ports 
                var allChecked=false;
                function CheckAll()
                {
                    $(".checkbox").each(function() { 
                      this.checked = "checked";                   
                    });
                }   
                function UncheckAll()
                {
                    $(".checkbox").each(function() { 
                      this.checked = "";                      
                    });
                }
                
                </script>
            
        <input type="hidden" name="host" value="'.htmlentities($host).'">

        
    <div class="sectionTitle">'.gettext('Template Host').'</div>
    
    <table>

    <tr>
    <td valign="top">
    ';
    
    // show host icon
    $img = get_object_icon_image($host);
    $imghtml = get_object_icon_html($img, "");
    $output .= $imghtml;
    
    $output.='
    <br class="nobr" />
    </td>
    <td><a href="'.get_host_status_detail_link($host).'" target="_blank"><b>'.htmlentities($host).'</b></a><br class="nobr" />
    </td>
    </tr>
    
    </table>

    <div class="sectionTitle">'.gettext('Template Services').'</div>
    
    <p>'.gettext('Specify the services from the template host that should cloned').'. 
    <br/>
    <b><a href="javascript:void(0);" onclick="CheckAll()" title="Check All">'.gettext('Check All').'</a> / 
                    <a href="javascript:void(0);" onclick="UncheckAll()" title="Uncheck All">'.gettext('Uncheck All').'</a></b></p>
    
    <table>
    
    <!--<tr><th></th><th>'.gettext('Service').'</th></tr>-->
    ';
    
    $args = array(
        "host_name" => $host,
        "is_active" => 1
        );
    $tservices = get_xml_service_objects($args);
    foreach ($tservices->service as $ts) {
        $sname = strval($ts->service_description);
        if (service_exists($host, $sname)) { //extra verification 
            $output.='<tr>
            <td><input type="checkbox" class="checkbox" name="services['.htmlentities($sname).']"  '.is_checked(grab_array_var($services,$sname)).'></td>
            <td><a href="'.get_service_status_detail_link($host,$sname).'" target="_blank"><b>'.htmlentities($sname).'</b></a></td>
            </tr>';
        }
    }
    
    
    $output.='
    </table>

    <div class="sectionTitle">'.gettext('Import / Cloning Data').'</div>
    
    <p>
    '.gettext('Enter addresses of new hosts that should be created by cloning the template host and services specified above').'.
    </p>
    
    <table style="margin-bottom: 20px;">

    <tr>
        <td>
            <label>Fields:</label><br class="nobr" />
        </td>
        <td>
            <table>
            <tr><th>'.gettext('Field').' 1</th><th>'.gettext('Field').' 2</th><th>'.gettext('Field').' 3</th><th>'.gettext('Field').' 4</th><th>'.gettext('Field').' 5</th></tr>
            <tr>
                <td>
                    <select name="field1">
                        <option value="ignore" >'.gettext('IGNORE').'</option>
                        <option value="address" '.is_selected($field1,"address").'>'.gettext('Address').'</option>
                        <option value="hostname" '.is_selected($field1,"hostname").'>'.gettext('Name').'</option>
                        <option value="hostalias" '.is_selected($field1,"hostalias").'>'.gettext('Description').'</option>
                        <option value="hostgroup" '.is_selected($field1,"hostgroup").'>'.gettext('Hostgroup').'</option>
                        <option value="parenthost" '.is_selected($field1,"parenthost").'>'.gettext('Parent Host').'</option>
                    </select>
                </td>
                <td>
                    <select name="field2">
                        <option value="ignore" >'.gettext('IGNORE').'</option>
                        <option value="address" '.is_selected($field2,"address").'>'.gettext('Address').'</option>
                        <option value="hostname" '.is_selected($field2,"hostname").'>'.gettext('Name').'</option>
                        <option value="hostalias" '.is_selected($field2,"hostalias").'>'.gettext('Description').'</option>
                        <option value="hostgroup" '.is_selected($field2,"hostgroup").'>'.gettext('Hostgroup').'</option>
                        <option value="parenthost" '.is_selected($field2,"parenthost").'>'.gettext('Parent Host').'</option>
                    </select>
                </td>
                <td>
                    <select name="field3">
                        <option value="ignore" >'.gettext('IGNORE').'</option>
                        <option value="address" '.is_selected($field3,"address").'>'.gettext('Address').'</option>
                        <option value="hostname" '.is_selected($field3,"hostname").'>'.gettext('Name').'</option>
                        <option value="hostalias" '.is_selected($field3,"hostalias").'>'.gettext('Description').'</option>
                        <option value="hostgroup" '.is_selected($field3,"hostgroup").'>'.gettext('Hostgroup').'</option>
                        <option value="parenthost" '.is_selected($field3,"parenthost").'>'.gettext('Parent Host').'</option>
                    </select>
                </td>
                <td>
                    <select name="field4">
                        <option value="ignore" >'.gettext('IGNORE').'</option>
                        <option value="address" '.is_selected($field4,"address").'>'.gettext('Address').'</option>
                        <option value="hostname" '.is_selected($field4,"hostname").'>'.gettext('Name').'</option>
                        <option value="hostalias" '.is_selected($field4,"hostalias").'>'.gettext('Description').'</option>
                        <option value="hostgroup" '.is_selected($field4,"hostgroup").'>'.gettext('Hostgroup').'</option>
                        <option value="parenthost" '.is_selected($field4,"parenthost").'>'.gettext('Parent Host').'</option>
                    </select>
                </td>
                <td>
                    <select name="field5">
                        <option value="ignore" >'.gettext('IGNORE').'</option>
                        <option value="address" '.is_selected($field5,"address").'>'.gettext('Address').'</option>
                        <option value="hostname" '.is_selected($field5,"hostname").'>'.gettext('Name').'</option>
                        <option value="hostalias" '.is_selected($field5,"hostalias").'>'.gettext('Description').'</option>
                        <option value="hostgroup" '.is_selected($field5,"hostgroup").'>'.gettext('Hostgroup').'</option>
                        <option value="parenthost" '.is_selected($field5,"parenthost").'>'.gettext('Parent Host').'</option>
                    </select>
                </td>
            </tr>
            </table>
            '.gettext('Specify the type of data that is present in the fields of the data below').'.<br><br>
        </td>
    </tr>
    
    <tr>
        <td valign="top">
            <label>Data:</label><br class="nobr" />
        </td>
        <td>
            <textarea name="csvdata" rows="6" cols="120">'.$csvdata.'</textarea>
            <div style="margin-bottom: 20px;">'.gettext('The addresses of new hosts that should be created by cloning the template host and services specified above.  Multiple fields should be separated by a comma.  One entry per line.').'</div>
        </td>
    </tr>

    <tr>
        <td><label>'.gettext("Options").':</label></td>
        <td>
            <input type="checkbox" value="1" name="overwrite" '.is_checked($overwrite, 1).'> '.gettext("Replace Parent Host and/or Hostgroup with the above selected (if any) instead of adding the given Parent and/or Hostgroup to the new host.").'
        </td>
    </tr>
    
    </table>
    
            ';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
        
            // Get variables that were passed to us
            $host = grab_array_var($inargs, "host");
            $csvdata = grab_array_var($inargs, "csvdata");
            $overwrite = grab_array_var($inargs, "overwrite", 0);

            // Grab all 5 fields
            for ($i = 1; $i < 6; $i++) {
                $fields[$i] = grab_array_var($inargs, "field" . $i);
            }

            $host_template = nagiosql_read_host_config_from_file($host);
            
            $services = "";
            $services_serial = grab_array_var($inargs, "services_serial", "");
            if ($services_serial != "") {
                $services = unserialize(base64_decode($services_serial));
            }
            if (!is_array($services)) {
                $services = grab_array_var($inargs, "services", array());
            }

            // check for errors
            $errors = 0;
            $errmsg = array();
            
            // Not sure why we were requiring services to be selected, so I removed them 6/21/2013 -SW
            //if(count($services)==0)
            //  $errmsg[$errors++]=gettext("No template services selected.");
                
            // Check for required field values
            $has_address = false;
            $has_non_unique = false;
            foreach ($fields as $field) {
                
                // Check for address
                if ($field == "address") {
                    $has_address = true;
                }

                // Check for non-unique within the fields
                $c = 0;
                foreach ($fields as $f2_check) {
                    if ($field == $f2_check && $field != "ignore") {
                        $c++;
                    }
                    if ($c > 1) {
                        $has_non_unique = true;
                    }
                }
            }

            // If no address, then complain
            if (!$has_address) {
                $errmsg[$errors++] = gettext("Address must be present in CSV fields.");
            }

            // If there are any non-unique values let's error
            if ($has_non_unique) {
                $errmsg[$errors++] = gettext("Import / cloning data fields must be unique.");
            }

            // check CSV data
            $csva1 = explode("\n", $csvdata);
            $csva2 = array_unique($csva1);
            $csva3 = array_filter($csva2);
            $csvarray = $csva3;
            if (count($csvarray) == 0) {
                $errmsg[$errors++] = gettext("No import / cloning data provided.");
            }
            
            if ($errors > 0) {
                $outargs[CONFIGWIZARD_ERROR_MESSAGES] = $errmsg;
                $result = 1;
            }
                
            break;

            

        case CONFIGWIZARD_MODE_GETSTAGE3OPTS:   
    
            $output .= gettext('Monitoring options will be inherited from the template host and services you selected.  Click Next to continue.');
            $result = CONFIGWIZARD_HIDE_OPTIONS;
            break;

        case CONFIGWIZARD_MODE_GETSTAGE3HTML:
        
            // Get variables that were passed to us
            $host = grab_array_var($inargs, "host");
            $csvdata = grab_array_var($inargs, "csvdata");
            $overwrite = grab_array_var($inargs, "overwrite", 0);

            // Grab all 5 fields
            for ($i = 1; $i < 6; $i++) {
                $fields[$i] = grab_array_var($inargs, "field" . $i);
            }

            $services = "";
            $services_serial = grab_array_var($inargs,"services_serial");
            if ($services_serial != "") {
                $services = unserialize(base64_decode($services_serial));
            } else {
                $services = grab_array_var($inargs, "services");
            }

            $serviceargs = "";
            $serviceargs_serial = grab_array_var($inargs, "serviceargs_serial");
            if ($serviceargs_serial != "") {
                $serviceargs = unserialize(base64_decode($serviceargs_serial));
            } else {
                $serviceargs = grab_array_var($inargs, "serviceargs");
            }

            $output = '<input type="hidden" name="host" value="'.htmlentities($host).'">
                       <input type="hidden" name="csvdata" value="'.htmlentities($csvdata).'">
                       <input type="hidden" name="field1" value="'.htmlentities($fields[1]).'">
                       <input type="hidden" name="field2" value="'.htmlentities($fields[2]).'">
                       <input type="hidden" name="field3" value="'.htmlentities($fields[3]).'">
                       <input type="hidden" name="field4" value="'.htmlentities($fields[4]).'">
                       <input type="hidden" name="field5" value="'.htmlentities($fields[5]).'">
                       <input type="hidden" name="overwrite" value="'.htmlentities($overwrite).'">
                       <input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'">
                       <input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'">';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
                
            break;
            
        case CONFIGWIZARD_MODE_GETSTAGE4OPTS:   
    
            $output .= gettext('Notification options will be inherited from the template host and services you selected.  Click Next to continue.');
            $result = CONFIGWIZARD_HIDE_OPTIONS;
            $outargs[CONFIGWIZARD_HIDDEN_OPTIONS] = array(
                CONFIGWIZARD_HIDE_NOTIFICATION_OPTIONS,
                CONFIGWIZARD_HIDE_NOTIFICATION_INTERVAL,
                CONFIGWIZARD_HIDE_NOTIFICATION_TARGETS,
                );

            break;

        case CONFIGWIZARD_MODE_GETSTAGE5OPTS:   
    
            $output .= gettext('Group membership will be inherited from the template host and services you selected unless you put hostgroup and/or parent host relationship data in.  Click Next to continue.');
            $result = CONFIGWIZARD_HIDE_OPTIONS;
            $outargs[CONFIGWIZARD_HIDDEN_OPTIONS] = array(
                CONFIGWIZARD_HIDE_HOSTGROUPS,
                CONFIGWIZARD_HIDE_SERVICEGROUPS,
                CONFIGWIZARD_HIDE_PARENT_HOSTS,
                );

            break;

        case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
            
            break;
            
        case CONFIGWIZARD_MODE_GETOBJECTS:
        
            $host = grab_array_var($inargs, "host", "");
            $csvdata = grab_array_var($inargs, "csvdata");
            $overwrite = grab_array_var($inargs, "overwrite", 0);

            // Grab all 5 fields
            for ($i = 1; $i < 6; $i++) {
                $fields[$i] = grab_array_var($inargs, "field" . $i);
            }
            
            $services_serial = grab_array_var($inargs, "services_serial", "");
            $serviceargs_serial = grab_array_var($inargs, "serviceargs_serial", "");
            
            $services = unserialize(base64_decode($services_serial));
            $serviceargs = unserialize(base64_decode($serviceargs_serial));
            
            // This will be the NEW objects array
            $objs = array();
            
            // Fetch template service settings from config file
            $service_templates = array();
            foreach ($services as $svc => $svcstate) {
                $service_templates[$svc] = nagiosql_read_service_config_from_file($host, $svc);
            }
        
            // Fetch template host settings from config file
            $host_template = nagiosql_read_host_config_from_file($host);
            
            // Get the CSV data into an array
            $csva1 = explode("\n", $csvdata);
            $csva2 = array_unique($csva1);
            $csva3 = array_filter($csva2);
            $csvarray = $csva3;
            
            // For each CSV row let's process it as a host (possibly a NEW host)
            foreach ($csvarray as $c) {
            
                $cf = explode(",", $c);
                
                // Grab all the values in the CSV array for this row
                $fv = array();
                for ($i = 0; $i < 5; $i++) {
                    $val = grab_array_var($cf, $i, "");
                    $fv[$i+1] = str_replace('"', '', $val); // Scott's fix for " in CSV data -JO
                }

                // Default all these...
                $address = "";
                $hostname = "";
                $hostalias = "";
                $hostgroup = "";
                $parenthost = "";

                // Add values to the correct variables
                for ($i = 1; $i < 6; $i++) {
                    switch ($fields[$i]) {
                        case "address":
                            $address = trim($fv[$i]);
                            break;
                        case "hostname":
                            $hostname = trim($fv[$i]);
                            break;
                        case "hostalias":
                            $hostalias = trim($fv[$i]);
                            break;
                        case "hostgroup":
                            $hostgroup = trim($fv[$i]);
                            break;
                        case "parenthost":
                            $parenthost = trim($fv[$i]);
                            break;
                    }
                }

                // Check for a valid address or bail
                if ($address == "") {
                    continue;
                }

                // If there's no hostname we can set it to the address
                if ($hostname == "") {
                    $hostname = $address;
                }
                
                // Replace hostgroup and parent host if they don't exist
                if (!host_exists($parenthost) || $parenthost == "") {
                    $parenthost = "null";
                }
                if (!hostgroup_exists($hostgroup)) {
                    $hostgroup = "null";
                }

                if ($hostalias == "") {
                    $hostalias = "null";
                }

                // Bail if the hostname isn't valid
                if (is_valid_host_name($hostname) == false) {
                    continue;
                }

                // Add the host
                if (!host_exists($hostname)) {

                    // The list of added things that the CSV is adding to a new host (hostname, address, etc)
                    $newhost = array(
                        "type" => OBJECTTYPE_HOST,
                        "use" => grab_array_var($host_template, "use", "generic-host"),
                        "host_name" => $hostname,
                        "address" => $address,
                        "alias" => $hostalias,
                        "hostgroups" => $hostgroup,
                        "parents" => $parenthost
                    );
                        
                    // These may or may not be specified in the config file and may or may not be added to the new config
                    $cvars = array( 
                                "check_command",
                                "icon_image",
                                "statusmap_image",
                                "_xiwizard",
                                "check_period", // Fix 09-23-12 per Ludmil
                                "check_interval",
                                "retry_interval",
                                "max_check_attempts",
                                "contacts",
                                "contact_groups",
                                "notifications_enabled", // Fix 09-23-12 per Ludmil
                                "notification_period",
                                "notification_interval",
                                "first_notification_delay",
                                "notification_options",
                                "use"
                            );

                    if ($overwrite == 0) {
                        array_push($cvars, "hostgroups", "parents");
                    }

                    // Loop through and set all HOST TEMPLATE variables to the NEW HOST
                    foreach ($cvars as $cv) {
                        $cvv = grab_array_var($host_template, $cv, "null");
                        if ($cvv != "") {
                            
                            // For parents and hostgroups let's append to what they may have given it in the CSV
                            // ONLY DO THIS IF THE OVERWRITE SELECTOR IS SET TO 0 (NOT OVERWRITING TEMPLATE'S)
                            if ($cv == "hostgroups" || $cv == "parents") {
                                if (!empty($cvv) || $cvv != "null") {
                                    $temp = explode(",", $cvv);

                                    $add = true;
                                    foreach ($temp as $t) {
                                        if ($t == $newhost[$cv]) {
                                            $add = false;
                                        }
                                    }

                                    if ($add) {
                                        $temp[] = $newhost[$cv];
                                    }

                                    if (count($temp) > 1) {
                                        $temp = array_diff($temp, array("null")); // Remove the "null" value
                                    }

                                    $newhost[$cv] = implode(",", $temp);
                                    continue;
                                }
                            }

                            $newhost[$cv] = $cvv;
                        }
                    }

                    $objs[] = $newhost;
                }
                    
                // Add services to the host
                foreach ($services as $svc => $svcstate) {
                                    
                    $newsvc = array(
                        "type" => OBJECTTYPE_SERVICE,
                        "host_name" => $hostname,
                        "service_description" => $svc
                    );

                    // These may or may not be specified in the config file
                    $cvars = array( "use",
                                    "check_command",
                                    "icon_image",
                                    "_xiwizard",
                                    "check_period", // Fix 09-23-12 per Ludmil
                                    "check_interval",
                                    "retry_interval",
                                    "max_check_attempts",
                                    "is_volatile",
                                    "stalking_options",
                                    "servicegroups",
                                    "active_checks_enabled",
                                    "passive_checks_enabled",
                                    "contacts",
                                    "contact_groups",
                                    "notifications_enabled", // Fix 09-23-12 per Ludmil
                                    "notification_period",
                                    "notification_interval",
                                    "first_notification_delay",
                                    "notification_options"
                                );

                    foreach ($cvars as $cv) {
                        $cvv = grab_array_var($service_templates[$svc], $cv, "null");
                        if ($cvv != "") {
                            $newsvc[$cv] = $cvv;
                        }
                    }

                    $objs[] = $newsvc;
                }
                
            }

            // return the object definitions to the wizard
            $outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
            
            break;
            
        default:
            break;          
        }
        
    return $output;
    }

    
function bulkhostimport_configwizard_get_fval()
{
    // Not sure what this does but not deleting it for reqs
}
?>
