<?php
// timeline.inc.php
// - Template file for highcharts timeline graph     

// Pass all args into template and return JSON code 
function fetch_timeline($args)
{   
    // Allow for height & width to be passed for resizing
    $height = grab_array_var($args, 'height', 500);
    $width = grab_array_var($args, 'width');
    $hs_url = grab_array_var($args, "hs_url");
    $render_mode = grab_array_var($args, "render_mode", "");

    // If no hovering
    $no_hover = "";
    $no_hover_fill = "";
    if ($render_mode == "pdf") {
        $no_hover = "enableMouseTracking: false,";
        $no_hover_fill = "fillColor: '#FFFFFF'";
    }

    // Check width
    if (!empty($width)) {
        $width = "width: {$width},";
    }

    // Create readable graph
    $args['title'] = str_replace("_", " ", $args['title']); // Replaces underscores with spaces
    $units = explode(" ", $args['UOM']);
    if (count($units) == 3) {
        if ($units[0] == $units[1] && $units[2] == "") {
            $args['UOM'] = $units[0]; // Fix double units of measurement
        }
    }

    // Check if we are going to have a subtitle
    $subtitle = ($args['subtitle']) ? "Click and drag mouse to zoom. Click legend to show/hide data sets" : "";

    // Begin heredoc string syntax 
    $graph = <<<GRAPH
        
        var COUNT = {$args['count']}; //total rrd entries fetched 
        var UOM = '{$args['UOM']}';
        var START = {$args['start']};   //Date.UTC(2011, 1, 21) ->added below for correct datatype
        var TITLE = '{$args['title']}'; 
        var CONTAINER = '{$args['container']}';
    
        //reset default colors 
        Highcharts.setOptions({
            colors: ['#058DC7', '#50B432', '#ED561B', '#DDDF00', '#24CBE5', '#64E572', '#FF9655', '#FFF263', '#6AF9C4'] 
        }); 
    
        //data points added below for correct datatype interpretation               
        //use browser's timezone offset for date        
        Highcharts.setOptions({
            global: { useUTC: false },
        });
                
            var chart;
            $(document).ready(function() {
                chart = new Highcharts.Chart({
                    chart: {
                        renderTo: CONTAINER,
                        zoomType: 'x',
                        spacingRight: 20,
                        height: {$height},
                        {$width}
                        animation: false
                    },
                    credits: {
                        enabled: false
                    },
                    title: {
                        //insert host/service name here 
                        text: TITLE
                    },
                    subtitle: {
                        text: '{$subtitle}'
                    },
                    xAxis: {
                        type: 'datetime',
                        maxZoom: {$args['increment']}*1000,  //max zoom is 5 minutes 
                        title: {
                            text: null
                        }
                    },
                    yAxis: {
                        title: {
                            text: UOM  // unit of measurement from perf data 
                        },
                        startOnTick: false,
                        showFirstLabel: false
                    },
                    tooltip: {
                        shared: true                    
                    },
                    legend: {
                        enabled: true
                    },
                    plotOptions: {
                        area: {
                            {$no_hover}
                            lineWidth: 1,
                            marker: {
                                enabled: false,
                                states: {
                                    hover: {
                                        enabled: true,
                                        radius: 5
                                    }
                                }
                            },
                            shadow: false,
                            states: {
                                hover: {
                                    lineWidth: 1                        
                                }
                            },
                            fillOpacity: 0.5
                        }
                    },
GRAPH;
// End heredoc syntax 
        
    // If there is actually data... ($args['nodata'] is a boolean)
    if ($args['nodata']) {
	
		// Display no data
		// TODO: Add "No Data" text to graph
		$nodata_text = "
			text = chart.renderer.text('No Data').add();
			textBBox = text.getBBox();
			tx = chart.plotLeft + (chart.plotWidth * 0.5) - (textBBox.width * 0.5);
			ty = chart.plotTop  + (chart.plotHeight * 0.5) - (textBBox.height * 0.5);
			text.attr({x: tx, y: ty});
		";
	
	} else {

        $graph .= "series: [";

        // Loop for multiple data sets in perfdata 
        $series = array(); 
        for($i=0;$i<count($args['datastrings']);$i++)
        { 
            $series[] = "
                    {
                        type: \"area\",
                        name: \"{$args['names'][$i]}\",                          
                        pointInterval: {$args['increment']}*1000,
                        pointStart: {$args['start']},
                        data: [
                            ".implode(', ',$args['datastrings'][$i])." 
                        ],
                        animation: false,
                        {$no_hover_fill}
                    }"; 
        }
            
        $graph .= implode(',', $series);
        $graph .= "]";
    }

    // End the highcharts graph syntax
    $graph .= " }, function(chart) {
                    chart.title.addClass('chartbutton');
                    chart.title.on('click', function() {
                        window.location = '" . $hs_url . "';
                    })
            });             
        });";
		
	// Add nodata text if it exists
	if (isset($nodata_text)) {
		$graph .= $nodata_text;
	}
	
    return $graph;      
}
?> 