<?php
// SWITCH CONFIG WIZARD
//
// Copyright (c) 2008-2011 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: switch.inc.php 1293 2014-04-25 18:55:07Z swilkerson $
//
// TODOS:
// * Smarter MRTG file update
//     Current implementation is naive in that it only looks for a single existing address/port match
//     Make it smarter by determining missing ports in the MRTG file and only adding those...

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
switch_configwizard_init();

function switch_configwizard_init(){
	
	$name="switch";
	
	$args=array(
		CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "2.0",
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => gettext("Monitor a network switch or router."),
		CONFIGWIZARD_DISPLAYTITLE => gettext("Network Switch / Router"),
		CONFIGWIZARD_FUNCTION => "switch_configwizard_func",
		CONFIGWIZARD_PREVIEWIMAGE => "switch.png",
		);
		 
	register_configwizard($name,$args);
	}


/**
 *
 * Generates the instructions to be passed to the command line to generate an MRTG configuration.
 *
 * @param $snmpopts Array - Given by the getstage1html
 * @param $address String - Address of the network device
 * @param $snmpversion String - Must be either 1, 2c, 3
 * @param $defaultspeed String - If nothing is returned by ifSpeed, use this value.
 * @return $cmd String - String to be executed
 */
function switch_configwizard_get_cfgmaker_cmd($snmpopts,$address,$snmpversion="1",$defaultspeed="100000000") {
    
    $cmd    = "/usr/bin/cfgmaker ";
    $args[] = "--show-op-down";
    $args[] = "--noreversedns";
    $args[] = "--zero-speed";
    $args[] = escapeshellarg($defaultspeed);
    if(empty($snmpopts['v3_username'])) {
        // Run SNMPv1, SNMPv2, SNMPv2c code here
        $username = $snmpopts['snmpcommunity'];
        $args[] = escapeshellarg("{$username}@{$address}:::::".$snmpversion);
    }
    else {
        // Run SNMPv3 code here
        $args[] = "--enablesnmpv3";
        $args[] = "--snmp-options=:::::3";
        if(!empty($snmpopts['v3_username'])) {
            $args[] = "--username=".escapeshellarg($snmpopts['v3_username']);
        }
        if(!empty($snmpopts['v3_auth_password'])) {
            $args[] = "--authprotocol=".escapeshellarg($snmpopts['v3_auth_proto']);
            $args[] = "--authpassword=".escapeshellarg($snmpopts['v3_auth_password']);
        }
        if(!empty($snmpopts['v3_priv_password'])) {
            $args[] = "--privprotocol=".escapeshellarg($snmpopts['v3_priv_proto']);
            $args[] = "--privpassword=".escapeshellarg($snmpopts['v3_priv_password']);
        }
        $args[] = "--contextengineid=0";
        $args[] = escapeshellarg($address);
    }
    $cmd .= implode(' ', $args);
    return $cmd;
}

function switch_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

	$wizard_name="switch";

	// initialize return code and output
	$result=0;
	$output="";
	
	// initialize output args - pass back the same data we got
	$outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


	switch($mode){
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:

            $address=grab_array_var($inargs, "address", "");
            $snmpversion=grab_array_var($inargs, "snmpversion", "2c");
            $snmpopts_serial=grab_array_var($inargs,"snmpopts_serial","");
            if($snmpopts_serial!="")
                $snmpopts=unserialize(base64_decode($snmpopts_serial));
            else {
                $snmpopts_default=array(
                    "snmpcommunity" => "public",
                    "v3_security_level" => "",
                    "v3_username" => "",
                    "v3_auth_password" => "",
                    "v3_priv_password" => "",
                    "v3_auth_proto" => "md5",
                    "v3_priv_proto" => "des",
                    );
                $snmpopts=grab_array_var($inargs,"snmpopts",$snmpopts_default);
                }
            $portnames=grab_array_var($inargs, "portnames", "number");
            $scaninterfaces=grab_array_var($inargs, "scaninterfaces", "on");
            $default_port_speed=grab_array_var($inargs,"default_port_speed",100000000);
            $warn_speed_in_percent=grab_array_var($inargs,"warn_speed_in_percent",50);
            $warn_speed_out_percent=grab_array_var($inargs,"warn_speed_out_percent",50);
            $crit_speed_in_percent=grab_array_var($inargs,"crit_speed_in_percent",80);
            $crit_speed_out_percent=grab_array_var($inargs,"crit_speed_out_percent",80);
			if(!switch_configwizard_checkversion()){
				$output="<br/><strong>" . gettext("Error: This wizard requires Nagios XI 2014 or later.") . "</strong>";
			}
			else {
            $output='
<script>
    $(document).ready(function() {
        $("#tabs").tabs();
        // Upon clicking the tabs, set the invisible radio selector
        // to be true, based on the tab clicked
        $("#selectv1").click(function() {
            $("#snmpversion").val("1");
        });
		$("#selectv2").click(function() {
            $("#snmpversion").val("2c");
        });
        $("#selectv3").click(function() {
            $("#snmpversion").val("3");
        });
        $("#selectv'.$snmpversion.'").click();
        // End of above commented section
    });
</script>

<div class="sectionTitle">'.gettext("Router/Switch Information").'</div>
<div style="height:70px;">
    <table>
        <tr>
            <td valign="top">
                <label>'.gettext("IP Address").':</label><br class="nobr" />
            </td>
            <td>
                <input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
                '.gettext("The IP address of the network device you'd like to monitor").'.<br class="nobr" />
            </td>
        </tr>
    </table>
</div>


    <input type="hidden" name="snmpversion" id="snmpversion" value="$snmpversion">


<div id="tabs">
    <ul>
        <li><a href="#snmpv2" id="selectv1">SNMPv1</a></li>
		<li><a href="#snmpv2" id="selectv2c">SNMPv2c</a></li>
        <li><a href="#snmpv3" id="selectv3">SNMPv3</a></li>
    </ul>
    <div id="snmpv2">
        <table>
            <tr>
                <td valign="top">
                    <label>'.gettext("SNMP Community").':</label><br class="nobr" />
                </td>
                <td>
                    <input type="text" size="20" name="snmpopts[snmpcommunity]" value="'.htmlentities($snmpopts['snmpcommunity']).'" class="textfield" /><br class="nobr" />
                    '.gettext("The SNMP community string required used to to query the network device").'.
                </td>
            </tr>
        </table>
    </div> <!-- Closes #snmpv2 -->

    <div id="snmpv3">
        <p>'.gettext("When using SNMP v3 you must specify authentication information").'.</p>

        <table>
            <tr>
                <td valign="top">
                <label>'.gettext("Security Level").':</label><br class="nobr" />
                </td>
                <td>
                    <select name="snmpopts[v3_security_level]">
                        <option value="noAuthNoPriv" '.is_selected($snmpopts["v3_security_level"],"noAuthNoPriv").'>noAuthNoPriv</option>
                        <option value="authNoPriv" '.is_selected($snmpopts["v3_security_level"],"authNoPriv").'>authNoPriv</option>
                        <option value="authPriv" '.is_selected($snmpopts["v3_security_level"],"authPriv").'>authPriv</option>
                    </select>
                    <br class="nobr" />
                </td>
            </tr>
            
            <tr>
                <td valign="top">
                    <label>'.gettext("Username").':</label><br class="nobr" />
                </td>
                <td>
                    <input type="text" size="20" name="snmpopts[v3_username]" value="'.htmlentities($snmpopts["v3_username"]).'" class="textfield" /><br class="nobr" />
                </td>
            </tr>

            <tr>
                <td valign="top">
                    <label>'.gettext("Authentification Password").':</label><br class="nobr" />
                </td>
                <td>
                    <input type="texs" size="20" name="snmpopts[v3_auth_password]" value="'.htmlentities($snmpopts["v3_auth_password"]).'" class="textfield" /><br class="nobr" />
                </td>
            </tr>

            <tr>
                <td valign="top">
                    <label>'.gettext("Privileged Password").':</label><br class="nobr" />
                </td>
                <td>
                    <input type="text" size="20" name="snmpopts[v3_priv_password]" value="'.htmlentities($snmpopts["v3_priv_password"]).'" class="textfield" /><br class="nobr" />
                </td>
            </tr>

            <tr>
                <td valign="top">
                    <label>'.gettext("Authentification Protocol").':</label><br class="nobr" />
                </td>
                <td>
                    <select name="snmpopts[v3_auth_proto]">
                        <option value="md5" '.is_selected($snmpopts["v3_auth_proto"],"md5").'>MD5</option>
                        <option value="sha" '.is_selected($snmpopts["v3_auth_proto"],"sha").'>SHA</option>
                    </select>
                    <br class="nobr" />
                </td>
            </tr>

            <tr>
                <td valign="top">
                    <label>'.gettext("Privileged Protocol").':</label><br class="nobr" />
                </td>
                <td>
                    <select name="snmpopts[v3_priv_proto]">
                        <option value="des" '.is_selected($snmpopts["v3_priv_proto"],"des").'>DES</option>
                        <option value="3desede" '.is_selected($snmpopts["v3_priv_proto"], "3desede").'>3-DES-EDE</option>
                        <option value="aescfb128" '.is_selected($snmpopts["v3_priv_proto"],"aescfb128").'>AES-128</option>
                        <option value="aescfb192" '.is_selected($snmpopts["v3_priv_proto"],"aescfb192").'>AES-192</option>
                        <option value="aescfb256" '.is_selected($snmpopts["v3_priv_proto"],"aescfb256").'>AES-256</option>
                    </select>
                    <br class="nobr" />
                </td>
            </tr>

        </table>
    </div> <!-- Closes #snmpv3 -->
</div> <!-- Closes #tabs -->

<div class="sectionTitle">'.gettext("Monitoring Options").'</div>
<table>
    <tr>
        <td>
            <label for="portnames">'.gettext("Monitor Using:").'</label>
        </td>
        <td>
            <select name="portnames">
                <option value="number" '.is_selected($portnames, "number").'>'.gettext("Port's Number").'</option>
                <option value="name" '.is_selected($portnames, "name").'>'.gettext("Port's Name").'</option>
            </select>
        </td>
    </tr>
    <tr>
        <td></td>
        <td>'.gettext("Select the port naming scheme that should be used. ").'</td>
    </tr>
    <tr>
        <td>
            <label for="scaninterfaces">'.gettext("Scan Interfaces").'</label>
        </td>
        <td>
            <input name="scaninterfaces" type="checkbox" '.is_checked($scaninterfaces).' />
        </td>
    </tr>
    <tr>
        <td></td>
        <td>'.gettext("Scan the switch or router to auto-detect interfaces that can be monitored for link up/down status and bandwidth usage.
The scanning process may take several seconds to complete.").'</td>
    </tr>
</table>

<div class="sectionTitle">'.gettext("Value Defaults").'</div>
<table>
    <tr>
        <td>
            <label for="warn_speed_in_percent">'.gettext("Warning Input Rate").':</label>
        </td>
        <td>
            <input class="textfield" type="text" value="'.$warn_speed_in_percent.'" name="warn_speed_in_percent" size="2" />%
        </td>
        <td>
            <label for="crit_speed_in_percent">'.gettext("Critical Input Rate").':</label>
        </td>
        <td>
            <input class="textfield" type="text" value="'.$crit_speed_in_percent.'" name="crit_speed_in_percent" size="2" />%
        </td>
    </tr>
    <tr>
        <td>
            <label for="warn_speed_in_percent">'.gettext("Warning Output Rate").':</label>
        </td>
        <td>
            <input class="textfield" type="text" value="'.$warn_speed_out_percent.'" name="warn_speed_out_percent" size="2" />%
        </td>
        <td>
            <label for="crit_speed_in_percent">'.gettext("Critical Output Rate").':</label>
        </td>
        <td>
            <input class="textfield" type="text" value="'.$crit_speed_out_percent.'" name="crit_speed_out_percent" size="2" />%
        </td>
    </tr>
    <tr>
        <td>
            <label for="default_port_speed">'.gettext("Default Port Speed").':</label>
        </td>
        <td>
            <input type="text" value="'.$default_port_speed.'" name="default_port_speed" size="10" class="textfield" /> bytes/second
        </td>
    </tr>
</table>';
		} // end else
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address","");
            $snmpopts=grab_array_var($inargs, "snmpopts", array());
			//~ $snmpcommunity=grab_array_var($inargs,"snmpcommunity");
			$scaninterfaces=grab_array_var($inargs,"scaninterfaces");
			$snmpversion=grab_array_var($inargs,"snmpversion","2c");
			$default_port_speed=grab_array_var($inargs,"default_port_speed",100000000);
			// check for errors
			$errors=0;
			$errmsg=array();
			//$errmsg[$errors++]="Address: '$address'";
			if(have_value($address)==false)
				$errmsg[$errors++]=gettext("No address specified.");
			else if(!valid_ip($address))
				$errmsg[$errors++]=gettext("Invalid IP address.");

            if(empty($snmpopts['snmpcommunity']) && empty($snmpopts['v3_username'])) {
                $errmsg[$errors++]=gettext("Must give either community or username.");
            }
            
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}

				
			// things look good so far...
			// if user wants to scan interfaces, immediately launch the command and start working on it....
			if($scaninterfaces=="on"){

				//echo "SCANNING!";
				
				$tmp_dir=get_tmp_dir();
				$outfile=$tmp_dir."/mrtgscan-".$address;
				$donefile=$outfile.".done";	
				
				// get rid of the old "done" file
				if(file_exists($donefile))
					unlink($donefile);
				
				// run MRTG's cfgmaker command in the background
				// TODO - see if data already exists in mrtg.cfg and skip this step....
				$cfgmaker_cmd=switch_configwizard_get_cfgmaker_cmd($snmpopts,$address,$snmpversion,$default_port_speed);
				$cmd=$cfgmaker_cmd." > ".$outfile." ; touch ".$donefile." > /dev/null &";
				exec($cmd);
				}
				
			break;
			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
            $snmpopts_serial=grab_array_var($inargs,"snmpopts_serial","");
            if($snmpopts_serial!="") {
                $snmpopts=unserialize(base64_decode($snmpopts_serial));
            }
            else {
                $snmpopts_default=array(
                    "snmpcommunity" => "public",
                    "v3_security_level" => "",
                    "v3_username" => "",
                    "v3_auth_password" => "",
                    "v3_priv_password" => "",
                    "v3_auth_proto" => "md5",
                    "v3_priv_proto" => "des",
                    );
                $snmpopts=grab_array_var($inargs,"snmpopts",$snmpopts_default);
                $snmpopts_serial=base64_encode(serialize($snmpopts));
            }
			$vendor=grab_array_var($inargs,"vendor","");
			$portnames=grab_array_var($inargs,"portnames");
			$scaninterfaces=grab_array_var($inargs,"scaninterfaces");
			$snmpversion=grab_array_var($inargs,"snmpversion","1");
			$default_port_speed=grab_array_var($inargs,"default_port_speed",100000000);
			$warn_speed_in_percent=grab_array_var($inargs,"warn_speed_in_percent",50);
			$warn_speed_out_percent=grab_array_var($inargs,"warn_speed_out_percent",50);
			$crit_speed_in_percent=grab_array_var($inargs,"crit_speed_in_percent",80);
			$crit_speed_out_percent=grab_array_var($inargs,"crit_speed_out_percent",80);
	
			$hostname=@gethostbyaddr($address);
			
			/*
			echo "SERVICES:<BR>";
			print_r($services);
			echo "SERVICEARGS:<BR>";
			print_r($serviceargs);
			*/
		
			$output='
			
		<input type="hidden" name="snmpversion" value="'.htmlentities($snmpversion).'" />	
		<input type="hidden" name="address" value="'.htmlentities($address).'" />
		<input type="hidden" name="vendor" value="'.htmlentities($vendor).'" />
        <input type="hidden" name="snmpopts_serial" value="'.$snmpopts_serial.'" />
		<input type="hidden" name="portnames" value="'.htmlentities($portnames).'" />
		<input type="hidden" name="scaninterfaces" value="'.htmlentities($scaninterfaces).'" />
		<input type="hidden" name="warn_speed_in_percent" value="'.htmlentities($warn_speed_in_percent).'" />
		<input type="hidden" name="crit_speed_in_percent" value="'.htmlentities($crit_speed_in_percent).'" />
		<input type="hidden" name="warn_speed_out_percent" value="'.htmlentities($warn_speed_out_percent).'" />
		<input type="hidden" name="crit_speed_out_percent" value="'.htmlentities($crit_speed_out_percent).'" />

	<div class="sectionTitle">'.gettext('Switch Details').'</div>
	
	<table>

	<tr>
	<td>
	<label>'.gettext('Switch/Router Address').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td>
	<label>'.gettext('Host Name:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="hostname" id="hostname" value="'.htmlentities($hostname).'" class="textfield" /><br class="nobr" />
	'.gettext('The name you\'d like to have associated with this switch or router.').'
	</td>
	</tr>

	</table>

	<div class="sectionTitle">'.gettext('Services').'</div>
	
	<p>'.gettext('Specify which services you\'d like to monitor for the switch or router.').'</p>
	
	<table>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" id="ping" name="services[ping]" checked>
	</td>
	<td>
	<b>'.gettext('Ping').'</b><br>
	'.gettext('Monitors the switch/router with an ICMP ping.  Useful for watching network latency and general uptime.').'<br><br>
	</td>
	</tr>
			';
			
			// TODO - add option to monitor switch environmental sensors
			
			$output.='
	</table>
			';

			if($scaninterfaces=="on"){
			
				// read results of MRTG's scan
				// TODO - if switch is already in mrtg.cfg, read that instead...
				$tmp_dir=get_tmp_dir();
				$outfile=$tmp_dir."/mrtgscan-".$address;
				$ports=switch_configwizard_read_walk_file($outfile,$address);
				
				//print_r($ports);
				
				$output.='
				
				<div class="sectionTitle">'.gettext('Bandwidth and Port Status').'</div>
				
				<script type="text/javascript">
				//check all ports 
				var allChecked=false;
				function switchCheckAll()
				{
					$(".portbox:checkbox").each(function() { 
					  this.checked = "checked";					  
					});
				}	
				function switchUncheckAll()
				{
					$(".portbox:checkbox").each(function() { 
					  this.checked = "";					  
					});
				}
                function bandwidthCheckAll()
				{
					$(".bandwidthbox:checkbox").each(function() { 
					  this.checked = "checked";					  
					});
				}	
				function bandwidthUncheckAll()
				{
					$(".bandwidthbox:checkbox").each(function() { 
					  this.checked = "";					  
					});
				}
                function statusCheckAll()
				{
					$(".statusbox:checkbox").each(function() { 
					  this.checked = "checked";					  
					});
				}	
				function statusUncheckAll()
				{
					$(".statusbox:checkbox").each(function() { 
					  this.checked = "";					  
					});
				}
				</script>
				
				';
				
				if(count($ports)>0){
				
					$output.='
					<p>'.gettext("Select the ports for which you'd like to monitor bandwidth and port status.  You may specify an optional port name to be associated with specific ports.").'</p>

					<table class="standardtable">
					<tr><th>'.gettext('Port').'<br/><a href="javascript:void(0);" onclick="switchCheckAll()" title="'.gettext('Check All Ports').'">'.gettext('Check').'</a> / 
					<a href="javascript:void(0);" onclick="switchUncheckAll()" title="'.gettext('Uncheck All Ports').'">'.gettext('Uncheck').'</a></th><th>'.gettext('Max Speed').'</th><th>'.gettext('Port Name').'</th><th>'.gettext('Bandwidth').'<br/><a href="javascript:void(0);" onclick="bandwidthCheckAll()" title="'.gettext('Check All Ports').'">'.gettext('Check').'</a> / 
					<a href="javascript:void(0);" onclick="bandwidthUncheckAll()" title="'.gettext('Uncheck All Ports').'">'.gettext('Uncheck').'</a></th><th>'.gettext('Port Status').'<br/><a href="javascript:void(0);" onclick="statusCheckAll()" title="'.gettext('Check All Ports').'">'.gettext('Check').'</a> / 
					<a href="javascript:void(0);" onclick="statusUncheckAll()" title="'.gettext('Uncheck All Ports').'">'.gettext('Uncheck').'</a></th></tr>
					';
					
					$x=0;
					foreach($ports as $port_num => $parr){
					
						$port_bytes=grab_array_var($parr,"max_bytes",0);
						// we'll use either description or number as the name later
						$port_description=grab_array_var($parr,"port_description",$port_num);
						$port_number=grab_array_var($parr,"port_number",$port_num);
						$port_long_desc = grab_array_var($parr,"port_long_description",$port_num);
						
						// remome illegal chars in portnames -SW
						// `~!$%^&*|'"<>?,()=\
						$badchars = explode(" ", "` ~ ! $ % ^ & * | ' \" < > ? , ( ) = \\ { } [ ]");
						$port_number=str_replace($badchars, " ", $port_number);
						$port_description=str_replace($badchars, " ", $port_description);
						$port_long_desc=str_replace($badchars, " ", $port_long_desc);
						
						// default to using port number for service name
						$port_name=gettext("Port ").$port_number;
						if($portnames=="name")
							$port_name=$port_long_desc; //changed to long description -MG 
							
						$x++;
					 
						$max_speed=switch_configwizard_get_readable_port_line_speed($port_bytes,$speed,$label);
						//$speed="mbps";
						$warn_in_speed=($speed*($warn_speed_in_percent/100));
						$warn_out_speed=($speed*($warn_speed_out_percent/100));
						$crit_in_speed=($speed*($crit_speed_in_percent/100));
						$crit_out_speed=($speed*($crit_speed_out_percent/100));
						
						// possible refomat speed values/labels
						switch_configwizard_recalculate_speeds($warn_in_speed,$warn_out_speed,$crit_in_speed,$crit_out_speed,$label);
						
						$rowclass="";
						if(($x%2)!=0)
							$rowclass.=" odd";
						else
							$rowclass.=" even";
					
						$output.='
						<tr class='.$rowclass.'>
						<td valign="top">
						<input type="checkbox" class="checkbox portbox" id="port_'.$port_num.'" name="services[port]['.$port_num.']" checked> 
						'.gettext('Port ').$port_num.'<br />'.
						$port_description
						.'</td>
						
						<td>
						'.$max_speed.'
						</td>

						<td>
						<input type="text" size="20" name="serviceargs[portname]['.$port_num.']" value="'.$port_name.'">
						</td>

						<td>
						<table>
						<tr>
						<td>
						<input type="checkbox" class="checkbox bandwidthbox" id="bandwidth_'.$port_num.'" name="serviceargs[bandwidth]['.$port_num.']" checked> 
						</td>
						<td>'.gettext('Rate In').':</td>
						<td>'.gettext('Rate Out').':</td>
						<td></td>
						<td>'.gettext('Rate In').':</td>
						<td>'.gettext('Rate Out').':</td>
						</tr>

						<tr>
						<td>
						<label>'.gettext('Warning').':</label>
						</td>
						<td>
						<input type="text" size="2" name="serviceargs[bandwidth_warning_input_value]['.$port_num.']" value="'.number_format($warn_in_speed).'">
						</td>
						<td>
						<input type="text" size="2" name="serviceargs[bandwidth_warning_output_value]['.$port_num.']" value="'.number_format($warn_out_speed).'">
						</td>
		
						<td>
						<label>'.gettext('Critical').':</label>
						</td>
						<td>
						<input type="text" size="2" name="serviceargs[bandwidth_critical_input_value]['.$port_num.']" value="'.number_format($crit_in_speed).'">
						</td>
						<td>
						<input type="text" size="2" name="serviceargs[bandwidth_critical_output_value]['.$port_num.']" value="'.number_format($crit_out_speed).'">
						</td>
						<td>
						<select name="serviceargs[bandwidth_speed_label]['.$port_num.']">
						<option value="Gbps" '.is_selected("Gbps",$label).'>'.gettext('Gbps').'</option>
						<option value="Mbps" '.is_selected("Mbps",$label).'>'.gettext('Mbps').'</option>
						<option value="Kbps" '.is_selected("Kbps",$label).'>'.gettext('Kbps').'</option>
						<option value="bps" '.is_selected("bps",$label).'>'.gettext('bps').'</option>
						</select>
						</td>
						</tr>
						</table>
				
						
						</td>
						<td>
						<input type="checkbox" class="checkbox statusbox" id="portstatus_'.$port_num.'" name="serviceargs[portstatus]['.$port_num.']" checked>
						</td>
						</tr>
						';
						}
					
					$output.='
					</table>
					';
					}
				else{
					$output.='
					<img src="'.theme_image("critical_small.png").'">
					<b>'.gettext('No ports were detected on the switch.').'</b>  '.gettext('Possible reasons for this include').':
					<ul>
					<li>'.gettext('The switch is currently down').'</li>
					<li>'.gettext('The switch does not exist at the address you specified').'</li>
					<li>'.gettext('SNMP support on the switch is disabled').'</li>
					</ul>
					';
					
					if(is_admin()==true){
						$cfgmaker_cmd=switch_configwizard_get_cfgmaker_cmd($snmpopts,$address);
						$output.='
						<br>
						<img src="'.theme_image("ack.png").'">
						<b>'.gettext('Troubleshooting Tip').':</b>
						<p>
						'.gettext('If you keep experiencing problems with the switch wizard scan, login to the Nagios XI server as the root user and execute the following command').':
						</p>
<pre>
'.$cfgmaker_cmd.'
</pre>
<p>
'.gettext('Send the output of the command and a description of your problem to the Nagios support team by posting to our online ').'<a href="http://support.nagios.com/forum/" target="_blank">'.gettext('support forum').'</a>.
</p>
						';
						}
					}

				}
			
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
		
			// get variables that were passed to us
			$hostname=grab_array_var($inargs,"hostname");
			$address=grab_array_var($inargs,"address");
			$portnames=grab_array_var($inargs,"portnames");
            $snmpopts_serial=grab_array_var($inargs,"snmpopts_serial","");
            if($snmpopts_serial!="") {
                $snmpopts=unserialize(base64_decode($snmpopts_serial));
            }
            else {
                $snmpopts_default=array(
                    "snmpcommunity" => "public",
                    "v3_security_level" => "",
                    "v3_username" => "",
                    "v3_auth_password" => "",
                    "v3_priv_password" => "",
                    "v3_auth_proto" => "md5",
                    "v3_priv_proto" => "des",
                    );
                $snmpopts=grab_array_var($inargs,"snmpopts",$snmpopts_default);
                $snmpopts_serial=base64_encode(serialize($snmpopts));
            }
            $snmpversion=grab_array_var($inargs,"snmpversion","1");
			$vendor=grab_array_var($inargs,"vendor");
			$scaninterfaces=grab_array_var($inargs,"scaninterfaces");
			$warn_speed_in_percent=grab_array_var($inargs,"warn_speed_in_percent",50);
			$warn_speed_out_percent=grab_array_var($inargs,"warn_speed_out_percent",50);
			$crit_speed_in_percent=grab_array_var($inargs,"crit_speed_in_percent",80);
			$crit_speed_out_percent=grab_array_var($inargs,"crit_speed_out_percent",80);
			
			// check for errors
			$errors=0;
			$errmsg=array();
			if(is_valid_host_name($hostname)==false)
				$errmsg[$errors++]=gettext("Invalid host name.");
				
			// TODO - check rate in/out warning and critical thresholds
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE3HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$vendor=grab_array_var($inargs,"vendor");
			$portnames=grab_array_var($inargs,"portnames");
            $snmpopts_serial=grab_array_var($inargs,"snmpopts_serial","");
            if($snmpopts_serial!="") {
                $snmpopts=unserialize(base64_decode($snmpopts_serial));
            }
            else {
                $snmpopts_default=array(
                    "snmpcommunity" => "public",
                    "v3_security_level" => "",
                    "v3_username" => "",
                    "v3_auth_password" => "",
                    "v3_priv_password" => "",
                    "v3_auth_proto" => "md5",
                    "v3_priv_proto" => "des",
                    );
                $snmpopts=grab_array_var($inargs,"snmpopts",$snmpopts_default);
                $snmpopts_serial=base64_encode(serialize($snmpopts));
            }
            $snmpversion=grab_array_var($inargs,"snmpversion","1");
			$scaninterfaces=grab_array_var($inargs,"scaninterfaces");
			$warn_speed_in_percent=grab_array_var($inargs,"warn_speed_in_percent",50);
			$warn_speed_out_percent=grab_array_var($inargs,"warn_speed_out_percent",50);
			$crit_speed_in_percent=grab_array_var($inargs,"crit_speed_in_percent",80);
			$crit_speed_out_percent=grab_array_var($inargs,"crit_speed_out_percent",80);

			$services=grab_array_var($inargs,"services");
			$serviceargs=grab_array_var($inargs,"serviceargs");
		
			$services_serial=grab_array_var($inargs,"services_serial",base64_encode(serialize($services)));
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial",base64_encode(serialize($serviceargs)));

			/*
			echo "REQUEST:<BR>";
			global $request;
			print_r($request);
			
			echo "SERVICES:<BR>";
			print_r($services);
			echo "SERVICEARGS:<BR>";
			print_r($serviceargs);
			*/
			

			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'" />
		<input type="hidden" name="hostname" value="'.htmlentities($hostname).'" />
		<input type="hidden" name="snmpopts_serial" value="'.$snmpopts_serial.'" />
        <input type="hidden" name="snmpversion" value="'.htmlentities($snmpversion).'" />	
		<input type="hidden" name="vendor" value="'.htmlentities($vendor).'" />
		<input type="hidden" name="portnames" value="'.htmlentities($portnames).'" />
		<input type="hidden" name="scaninterfaces" value="'.htmlentities($scaninterfaces).'" />
		<input type="hidden" name="warn_speed_in_percent" value="'.htmlentities($warn_speed_in_percent).'" />
		<input type="hidden" name="crit_speed_in_percent" value="'.htmlentities($crit_speed_in_percent).'" />
		<input type="hidden" name="warn_speed_out_percent" value="'.htmlentities($warn_speed_out_percent).'" />
		<input type="hidden" name="crit_speed_out_percent" value="'.htmlentities($crit_speed_out_percent).'" />
		<input type="hidden" name="services_serial" value="'.$services_serial.'" />
		<input type="hidden" name="serviceargs_serial" value="'.$serviceargs_serial.'" />
		
		<!-- SERVICES='.serialize($services).'<BR>
		SERVICEARGS='.serialize($serviceargs).'<BR> -->
		
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
				
			break;
			
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			
			$output='
			
			';
			break;
			
		case CONFIGWIZARD_MODE_GETOBJECTS:
		
			$hostname=grab_array_var($inargs,"hostname","");
			$address=grab_array_var($inargs,"address","");
            $snmpopts_serial=grab_array_var($inargs,"snmpopts_serial","");
            if($snmpopts_serial!="") {
                $snmpopts=unserialize(base64_decode($snmpopts_serial));
            }
            else {
                $snmpopts_default=array(
                    "snmpcommunity" => "public",
                    "v3_security_level" => "",
                    "v3_username" => "",
                    "v3_auth_password" => "",
                    "v3_priv_password" => "",
                    "v3_auth_proto" => "md5",
                    "v3_priv_proto" => "des",
                    );
                $snmpopts=grab_array_var($inargs,"snmpopts",$snmpopts_default);
                $snmpopts_serial=base64_encode(serialize($snmpopts));
            }
            $snmpversion=grab_array_var($inargs,"snmpversion","1");
			$portnames=grab_array_var($inargs,"portnames");
			$scaninterfaces=grab_array_var($inargs,"scaninterfaces");
			$vendor=grab_array_var($inargs,"vendor");
			
			$hostaddress=$address;
			
			$services_serial=grab_array_var($inargs,"services_serial","");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
			
			$services=unserialize(base64_decode($services_serial));
			$serviceargs=unserialize(base64_decode($serviceargs_serial));
			
			//echo "SERVICES:<BR>";
			//print_r($services);
			//echo "SERVICEARGS:<BR>";
			//print_r($serviceargs);
			
			// save data for later use in re-entrance
			$meta_arr=array();
			$meta_arr["hostname"]=$hostname;
			$meta_arr["address"]=$address;
			$meta_arr["snmpopts_serial"]=$snmpopts_serial;
            $meta_arr["snmpversion"]=$snmpversion;
			$meta_arr["portnames"]=$portnames;
			$meta_arr["scaninterfaces"]=$scaninterfaces;
			$meta_arr["vendor"]=$vendor;
			$meta_arr["services"]=$services;
			$meta_arr["serivceargs"]=$serviceargs;
			save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);			
			
			
			$objs=array();
			
			if(!host_exists($hostname)){
				$objs[]=array(
					"type" => OBJECTTYPE_HOST,
					"use" => "xiwizard_switch_host",
					"host_name" => $hostname,
					"address" => $hostaddress,
					"icon_image" => "switch.png",
					"statusmap_image" => "switch.png",
					"_xiwizard" => $wizard_name,
					);
				}
				
			$have_bandwidth=false;
				
			// see which services we should monitor
			foreach($services as $svc => $svcstate){
			
				//echo "PROCESSING: $svc -> $svcstate<BR>\n";
		
				switch($svc){
				
					case "ping":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Ping",
							"use" => "xiwizard_switch_ping_service",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "port":
					
						foreach($svcstate as $portnum => $portstate){
							//echo "HAVE PORT $portnum<BR>\n";
							
							$portname=gettext("Port ").$portnum;
							if(array_key_exists("portname",$serviceargs)){
								if(array_key_exists($portnum,$serviceargs["portname"])){
									$portname=$serviceargs["portname"][$portnum];
                                    $badchars = explode(" ", "` ~ ! $ % ^ & * | ' \" < > ? , ( ) = / \\ { } [ ] ;");
                                    $portname=str_replace($badchars, " ", $portname);
									}
								}
								
							// monitor bandwidth
							if(array_key_exists("bandwidth",$serviceargs)){
								if(array_key_exists($portnum,$serviceargs["bandwidth"])){
									//echo "MONITOR BANDWIDTH ON $portnum<BR>\n";
									
									$have_bandwidth=true;
									
									$warn_pair=$serviceargs["bandwidth_warning_input_value"][$portnum].",".$serviceargs["bandwidth_warning_output_value"][$portnum];
									$crit_pair=$serviceargs["bandwidth_critical_input_value"][$portnum].",".$serviceargs["bandwidth_critical_output_value"][$portnum];
									
									switch($serviceargs["bandwidth_speed_label"][$portnum]){
										case "Gbps":
											$label="G";
											break;
										case "Mbps":
											$label="M";
											break;
										case "Kbps":
											$label="K";
											break;
										default:
											$label="B";
											break;
										}
									
									$objs[]=array(
										"type" => OBJECTTYPE_SERVICE,
										"host_name" => $hostname,
										"service_description" => $portname." Bandwidth",
										"use" => "xiwizard_switch_port_bandwidth_service",
										"check_command" => "check_xi_service_mrtgtraf!".$hostaddress."_".$portnum.".rrd!".$warn_pair."!".$crit_pair."!".$label,
										"_xiwizard" => $wizard_name,
										);
									}
								}

							// monitor port status
							if(array_key_exists("portstatus",$serviceargs)){
								if(array_key_exists($portnum,$serviceargs["portstatus"])){
									//echo "MONITOR PORT STATUS ON $portnum<BR>\n";
                                    if($snmpversion != 3 ) {
                                        $objs[]=array(
                                        "type" => OBJECTTYPE_SERVICE,
                                        "host_name" => $hostname,
                                        "service_description" => $portname." Status",
                                        "use" => "xiwizard_switch_port_status_service",
                                        "check_command" => "check_xi_service_ifoperstatus!".$snmpopts['snmpcommunity']."!".$portnum."!-v ".(int)$snmpversion,
                                        "_xiwizard" => $wizard_name,
                                        );
									} else {
                                        $objs[]=array(
										"type" => OBJECTTYPE_SERVICE,
										"host_name" => $hostname,
										"service_description" => $portname." Status",
										"use" => "xiwizard_switch_port_status_service",
										"check_command" => "check_xi_service_ifoperstatusnag!{$portnum}!-v {$snmpversion} -u {$snmpopts['v3_username']} -A {$snmpopts['v3_auth_password']} -X {$snmpopts['v3_priv_password']} -l {$snmpopts['v3_security_level']}",
										"_xiwizard" => $wizard_name,
										);
									}
								}
							}
                        }
						break;
					
					default:
						break;
					}
				}
				
			//echo "OBJECTS:<BR>";
			//print_r($objs);
			//exit();
			
			// tell MRTG to start monitoring the switch
			if($have_bandwidth==true){
				$tmp_dir=get_tmp_dir();
				$outfile=$tmp_dir."/mrtgscan-".$address;
				switch_configwizard_add_walk_file_to_mrtg($outfile,$address);
				//echo "ADDED WALK FILE TO MRTG...";
				}
			//else
			//	echo "WE DON'T HAVE BANDWIDTH...";

			// return the object definitions to the wizard
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
		
			break;
			
		default:
			break;			
		}
		
	return $output;
	}
	
function switch_configwizard_read_walk_file($f,$address){

	$output=array();

	// open the walk file for reading
	$fi=fopen($f,"r");
	if($fi){
	
		while(!feof($fi)){
		
			$buf=fgets($fi);
			
			// skip comments
			$pos=strpos($buf,"#");
			if($pos!==false)
				continue;
				
			// found the target line (contains port number)
			if(preg_match('/Target\['.$address.'_([0-9\.]+)\]/',$buf,$matches)){
				$port_number=$matches[1];
				//echo "FOUND PORT $port_number<BR>\n";
				if(!array_key_exists($port_number,$output)){
					$output[$port_number]=array(
						"port_number" => $port_number,
						"port_description" => gettext("Port ").$port_number,
						"max_bytes" => 0,
						"port_long_description" => gettext("Port ").$port_number,
						);
					}			
				}
			// we have the port speed
			if(preg_match('/MaxBytes\['.$address.'_([0-9\.]+)\]: ([0-9\.]+)/',$buf,$matches)){
				$port_number=$matches[1];
				$max_bytes=$matches[2];
				//echo "PORT $port_number SPEED IS $max_bytes<BR>\n";
				//$output[$port_number]=$max_bytes;
				
				if(!array_key_exists($port_number,$output)){
					$output[$port_number]=array(
						"port_number" => $port_number,
						"port_description" => gettext("Port ").$port_number,
						"max_bytes" => $max_bytes,
						"port_long_description" => gettext("Port ").$port_number,
						);
					}
				else
					$output[$port_number]["max_bytes"]=$max_bytes;

				}
				// we found the description
				//modified so that the short description will replace port number if found
				if(preg_match('/MRTG_INT_DESCR=/',$buf,$matches))
				{
					//key string
					 $key = 'MRTG_INT_DESCR="';
					//find position of value and grab substring
					$position = strpos($buf, $key) + strlen($key);
					$short_descrip = substr( $buf, $position, (strlen($buf)) );
					//strip quotes and spaces
					$short_descrip = trim(str_replace('"', NULL, $short_descrip));
					//echo $short_descrip.'<br />';
					// save the description
					$output[$port_number]["port_description"]=$short_descrip;
					$output[$port_number]["port_long_description"]=$short_descrip;
					$longKey = "<td>".$short_descrip;
				}
				
				//check for user defined description 
				if(isset($longKey) && strpos($buf,$longKey)) 
				{
					$position = strpos($buf, $longKey) + strlen($longKey);
					$long_descrip = substr( $buf, $position, (strlen($buf)) );
					//strip td tag and spaces
					$long_descrip = trim(str_replace("</td>", NULL, $long_descrip));
					// save the description
					if($long_descrip != '') $output[$port_number]["port_long_description"]=$long_descrip;

				}

			}//end IF FILE is open

			
		fclose($fi);
		}
		
	//print_r($output);
	
	return $output;
	}
	
function switch_configwizard_add_walk_file_to_mrtg($f, $address)
{
	$debug=false;

	$mrtg_cfg="/etc/mrtg/mrtg.cfg";
    $mrtg_conf_dir = "/etc/mrtg/conf.d";
    $address_config = "{$address}.cfg";
    
    if($debug) {
        echo "Checking for existing config for $address at {$address}.cfg.";
        
        $dir_contents = scandir($mrtg_conf_dir);
        if(in_array($address_config, $dir_contents) === true) {
            echo "Config exists, it will be overwritten.";
        } else {
            echo "Config does not exist, it will be created.";
        }
    }

	// Open the devices config file for writing.
    $absolute_address_config = "{$mrtg_conf_dir}/{$address_config}";
	$fo=fopen($mrtg_cfg,"w");
    
	if(!$fo){
        
		if($debug) {
			echo "UNABLE TO OPEN {$mrtg_cfg} FOR APPENDING!<br>";
        }
		return false;
    }
		
	// open the walk file for reading.
	$fi=fopen($f, "r");
	if($fi) {
	
		fprintf($fo,"\n\n#### ADDED BY NAGIOSXI (USER: %s, DATE: %s) ####\n",get_user_attr(0,"username"),get_datetime_string(time()));
		
		while(!feof($fi)) {
			$buf=fgets($fi);
			fputs($fo, $buf);
        }
    }
		
	fclose($fo);
	
	// immediately tell mrtg to generate data from the new walk file 
	// if we didn't do this, nagios might send alerts about missing rrd files!
	$cmd="mrtg {$f} &";
	exec($cmd);

	return true;
}
	
function switch_configwizard_get_readable_port_line_speed($max_bytes,&$speed,&$label){

	//$bps=$max_bytes/8;
	$bps=$max_bytes*8;

	$kbps=$bps/1e3;
	$mbps=$bps/1e6;
	$gbps=$bps/1e9;
	
	if($gbps>=1){
		$speed=$gbps;
		$label="Gbps";
		}
	else if($mbps>=1){
		$speed=$mbps;
		$label="Mbps";
		}
	else if($kbps>=1){
		$speed=$kbps;
		$label="Kbps";
		}
	else{
		$speed=$bps." bps";
		$label="bps";
		}
		
	$output=number_format($speed,2)." ".$label;
	
	return $output;
	}
	
	
function switch_configwizard_recalculate_speeds(&$warn_in_speed,&$warn_out_speed,&$crit_in_speed,&$crit_out_speed,&$label){

	while(1){
	
		if($label=="bps")
			break;
	
		$maxval=max($warn_in_speed,$warn_out_speed,$crit_in_speed,$crit_out_speed);
		
		if($maxval<1){
		
			switch($label){
				case "Gbps":
					//echo "GBPS=$warn_in_speed<BR>";
					$label="Mbps";
					break;
				case "Mbps":
					$label="Kbps";
					break;
				case "Kbps":
					$label="bps";
					break;
				default:
					break;
				}

			// bump down a level
			$warn_in_speed*=1000;
			$warn_out_speed*=1000;
			$crit_in_speed*=1000;
			$crit_out_speed*=1000;
			
			}
		else
			break;
		}
		
	}
function switch_configwizard_checkversion()
{
    if (!function_exists('get_product_release'))
        return false;
    if (get_product_release() < 399)
        return false;
    if (!function_exists('use_2014_features') || !use_2014_features())
        return false;

    return true;
}
?>
